#ifndef CONFIGURATION_H
#define CONFIGURATION_H

#include "color.h"

typedef struct {
   double pos[2]; /* x and y coordinate, z is assumed to be 0 */
   double strength; /* scaling factor for the strength of the magnetic field */
   double size; /* size of the magnet;
      if the pendelum slows down in this area it is assumed
      to stay at this magnet */
   Color color; /* color representing this magnet */
} Magnet;

typedef struct {
   Magnet* magnets; /* pointer to array of magnets */
   unsigned int number_of_magnets;
   double friction; /* friction coefficient */
   double deltat; /* time period over which we use the numerical integration */
   double hooke_factor; /* factor k in F = k X
      where X the distance from (0,0) */
   double pendulum_height; /* height of the pendulum over the magnets */
   double threshold; /* if the velocity falls below this threshold,
      and if we are close enough to one of the magnets, the simulation stops */
   unsigned int max_iterations; /* maximal number of iterators */
   double center_x; double center_y;
   double horizontal_diameter;
   unsigned int width; unsigned int height;
} Configuration;

Configuration* get_conf_from_args(char* cmdname, int* argc_p, char*** argv_p);

#endif
