#include <stdio.h>
#include <stdlib.h>
#include "simulation.h"
#include "graphics.h"

int main(int argc, char** argv) {
   char* cmdname = *argv++; --argc;
   Configuration* conf = get_conf_from_args(cmdname, &argc, &argv);
   if (!conf) exit(1);
   if (!conf->magnets) {
      fprintf(stderr, "%s: no magnets specified\n", cmdname);
      exit(1);
   }
   if (argc != 1) {
      fprintf(stderr, "%s: output file expected as last arguments\n", cmdname);
      exit(1);
   }
   char* output_file = *argv++; --argc;

   double resolution = conf->width / conf->horizontal_diameter;
   double xmin = conf->center_x - conf->horizontal_diameter / 2;
   double vertical_diameter = conf->height / resolution;
   double ymax = conf->center_y + vertical_diameter / 2;

   Color (*pixels)[conf->height][conf->width] =
      malloc(sizeof(Color) * conf->height * conf->width);
   if (!pixels) {
      fprintf(stderr, "%s: out of memory\n", cmdname);
      exit(1);
   }
   for (unsigned int j = 0; j < conf->height; ++j) {
      for (unsigned int i = 0; i < conf->width; ++i) {
	 double x = xmin + i / resolution;
	 double y = ymax - j / resolution;
	 SimulationResult res = simulate(x, y, conf);
	 if (res.success) {
	    Magnet* magnet = conf->magnets + res.magnet_index;
	    (*pixels)[j][i] = magnet->color;
	 } else {
	    (*pixels)[j][i] = (Color){.red = 0, .green = 0, .blue = 0};
	 }
      }
   }
   if (!gen_jpeg(conf->height, conf->width, *pixels, output_file)) {
      exit(2);
   }
}
